@@ -326,7 +326,6 @@ double MCMCAlgorithm::acceptRejectSynthesisRateLevelForAllGenes(Genome& genome,
 void MCMCAlgorithm::acceptRejectCodonSpecificParameter(Genome& genome, Model& model, int iteration)
 {
 	//double acceptanceRatioForAllMixtures = 0.0;
-	double posterior;
 	std::vector<double> acceptanceRatioForAllMixtures(5,0.0);
 	unsigned size = model.getGroupListSize();
 
@@ -341,13 +340,12 @@ void MCMCAlgorithm::acceptRejectCodonSpecificParameter(Genome& genome, Model& mo
         /*if ((iteration % thinning) == 0)
         {
             my_print("The returned logLikelihood Ratio is: %\n", acceptanceRatioForAllMixtures[0]);
-            my_print("The Returned Threshhold is: %\n", threshold);
+            my_print("The returned Threshhold is: %\n", threshold);
         }*/
 
 		if (threshold < acceptanceRatioForAllMixtures[0] && std::isfinite(acceptanceRatioForAllMixtures[0]))
 		{
 			// moves proposed codon specific parameters to current codon specific parameters
-			posterior = acceptanceRatioForAllMixtures[4]; //unassigned will be 0
 			model.updateCodonSpecificParameter(grouping);
 			if ((iteration % thinning) == 0)
 			{
@@ -357,7 +355,6 @@ void MCMCAlgorithm::acceptRejectCodonSpecificParameter(Genome& genome, Model& mo
 		}
 		else
 		{
-			posterior = acceptanceRatioForAllMixtures[3];
 			if ((iteration % thinning) == 0)
 			{
 				likelihoodTrace[(iteration / thinning)] = acceptanceRatioForAllMixtures[1];
@@ -370,8 +367,6 @@ void MCMCAlgorithm::acceptRejectCodonSpecificParameter(Genome& genome, Model& mo
 			model.updateCodonSpecificParameterTrace(iteration/thinning, grouping);
 		}
 	}
-	//return posterior
-
 }
 
 
@@ -447,7 +442,7 @@ void MCMCAlgorithm::run(Genome& genome, Model& model, unsigned numCores, unsigne
 	// set the last iteration to the max iterations,
 	// this way if the MCMC doesn't exit based on Geweke score, it will use the max iteration for posterior means
 	model.setLastIteration(samples);
-	for (unsigned iteration = 1u; iteration <= maximumIterations; iteration++)
+	for (int iteration = 1u; iteration <= maximumIterations; iteration++)
 	{
 		if (writeRestartFile)
 		{
@@ -608,7 +603,7 @@ void MCMCAlgorithm::varyInitialConditions(Genome& genome, Model& model, unsigned
 		// prior on phi values -> take prior into account, but only the prior no likelihood
 		if (estimateSynthesisRate)
 		{
-			int numGenes = genome.getGenomeSize();
+			unsigned numGenes = genome.getGenomeSize();
 			unsigned numSynthesisRateCategories = model.getNumSynthesisRateCategories();
 			for (unsigned i = 0u; i < numGenes; i++)
 			{
